@@ -14,11 +14,14 @@
 
 # pylint: disable=too-many-ancestors
 
+import json
+
 import marshmallow
 import requests
 import semantic_version
 from marshmallow import Schema, ValidationError, fields, validate, validates
 
+from platformio.clients.http import fetch_remote_content
 from platformio.package.exception import ManifestValidationError
 from platformio.util import memoized
 
@@ -84,7 +87,7 @@ class StrictListField(fields.List):
 
 
 class AuthorSchema(StrictSchema):
-    name = fields.Str(required=True, validate=validate.Length(min=1, max=50))
+    name = fields.Str(required=True, validate=validate.Length(min=1, max=100))
     email = fields.Email(validate=validate.Length(min=1, max=50))
     maintainer = fields.Bool(default=False)
     url = fields.Url(validate=validate.Length(min=1, max=255))
@@ -149,7 +152,15 @@ class ExampleSchema(StrictSchema):
 
 class ManifestSchema(BaseSchema):
     # Required fields
-    name = fields.Str(required=True, validate=validate.Length(min=1, max=100))
+    name = fields.Str(
+        required=True,
+        validate=[
+            validate.Length(min=1, max=100),
+            validate.Regexp(
+                r"^[^:;/,@\<\>]+$", error="The next chars [:;/,@<>] are not allowed"
+            ),
+        ],
+    )
     version = fields.Str(required=True, validate=validate.Length(min=1, max=50))
 
     # Optional fields
@@ -240,9 +251,9 @@ class ManifestSchema(BaseSchema):
     @staticmethod
     @memoized(expire="1h")
     def load_spdx_licenses():
-        r = requests.get(
+        version = "3.10"
+        spdx_data_url = (
             "https://raw.githubusercontent.com/spdx/license-list-data"
-            "/v3.9/json/licenses.json"
+            "/v%s/json/licenses.json" % version
         )
-        r.raise_for_status()
-        return r.json()
+        return json.loads(fetch_remote_content(spdx_data_url))
