@@ -14,6 +14,7 @@
 
 import os
 import re
+import tarfile
 
 import jsondiff
 import pytest
@@ -82,7 +83,7 @@ def test_library_json_parser():
     },
     "dependencies": [
         {"name": "deps1", "version": "1.0.0"},
-        {"name": "@owner/deps2", "version": "1.0.0", "frameworks": "arduino, espidf"},
+        {"name": "@owner/deps2", "version": "1.0.0", "platforms": "*", "frameworks": "arduino, espidf"},
         {"name": "deps3", "version": "1.0.0", "platforms": ["ststm32", "sifive"]}
     ]
 }
@@ -100,6 +101,7 @@ def test_library_json_parser():
                 {
                     "name": "@owner/deps2",
                     "version": "1.0.0",
+                    "platforms": ["*"],
                     "frameworks": ["arduino", "espidf"],
                 },
                 {"name": "deps1", "version": "1.0.0"},
@@ -170,7 +172,7 @@ def test_module_json_parser():
             "name": "YottaLibrary",
             "description": "This is Yotta library",
             "homepage": "https://yottabuild.org",
-            "keywords": ["mbed", "Yotta"],
+            "keywords": ["mbed", "yotta"],
             "license": "Apache-2.0",
             "platforms": ["*"],
             "frameworks": ["mbed"],
@@ -196,10 +198,12 @@ def test_library_properties_parser():
     contents = """
 name=TestPackage
 version=1.2.3
-author=SomeAuthor <info AT author.com>
+author=SomeAuthor <info AT author.com>, Maintainer Author (nickname) <www.example.com>
+maintainer=Maintainer Author (nickname) <www.example.com>
 sentence=This is Arduino library
 customField=Custom Value
 depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
+ignore_empty_field=
 """
     raw_data = parser.LibraryPropertiesManifestParser(contents).as_dict()
     raw_data["dependencies"] = sorted(raw_data["dependencies"], key=lambda a: a["name"])
@@ -215,7 +219,10 @@ depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
             "export": {
                 "exclude": ["extras", "docs", "tests", "test", "*.doxyfile", "*.pdf"]
             },
-            "authors": [{"email": "info@author.com", "name": "SomeAuthor"}],
+            "authors": [
+                {"name": "SomeAuthor", "email": "info@author.com"},
+                {"name": "Maintainer Author", "maintainer": True},
+            ],
             "keywords": ["uncategorized"],
             "customField": "Custom Value",
             "depends": "First Library (=2.0.0), Second Library (>=1.2.0), Third",
@@ -276,7 +283,7 @@ depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
     # Author + Maintainer
     data = parser.LibraryPropertiesManifestParser(
         """
-author=Rocket Scream Electronics
+author=Rocket Scream Electronics <broken-email.com>
 maintainer=Rocket Scream Electronics
 """
     ).as_dict()
@@ -478,7 +485,7 @@ depends=First Library (=2.0.0), Second Library (>=1.2.0), Third
     contents = """
 name=Mozzi
 version=1.0.3
-author=Tim Barrass and contributors as documented in source, and at https://github.com/sensorium/Mozzi/graphs/contributors
+author=Lorem Ipsum is simply dummy text of the printing and typesetting industry Lorem Ipsum has been the industry's standard dummy text ever since the 1500s  when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries  but also the leap into electronic typesetting  remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages  and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
 maintainer=Tim Barrass <faveflave@gmail.com>
 sentence=Sound synthesis library for Arduino
 paragraph=With Mozzi, you can construct sounds using familiar synthesis units like oscillators, delays, filters and envelopes.
@@ -497,6 +504,7 @@ includes=MozziGuts.h
         ),
     ).as_dict()
 
+    errors = None
     try:
         ManifestSchema().load_manifest(raw_data)
     except ManifestValidationError as e:
@@ -543,8 +551,8 @@ def test_platform_json_schema():
   "name": "atmelavr",
   "title": "Atmel AVR",
   "description": "Atmel AVR 8- and 32-bit MCUs deliver a unique combination of performance, power efficiency and design flexibility. Optimized to speed time to market-and easily adapt to new ones-they are based on the industrys most code-efficient architecture for C and assembly programming.",
-  "url": "http://www.atmel.com/products/microcontrollers/avr/default.aspx",
-  "homepage": "http://platformio.org/platforms/atmelavr",
+  "keywords": "arduino, atmel, avr",
+  "homepage": "http://www.atmel.com/products/microcontrollers/avr/default.aspx",
   "license": "Apache-2.0",
   "engines": {
     "platformio": "<5"
@@ -602,7 +610,8 @@ def test_platform_json_schema():
                 "on the industrys most code-efficient architecture for C and "
                 "assembly programming."
             ),
-            "homepage": "http://platformio.org/platforms/atmelavr",
+            "keywords": ["arduino", "atmel", "avr"],
+            "homepage": "http://www.atmel.com/products/microcontrollers/avr/default.aspx",
             "license": "Apache-2.0",
             "repository": {
                 "url": "https://github.com/platformio/platform-atmelavr.git",
@@ -624,7 +633,9 @@ def test_package_json_schema():
 {
     "name": "tool-scons",
     "description": "SCons software construction tool",
-    "url": "http://www.scons.org",
+    "keywords": "SCons, build",
+    "homepage": "http://www.scons.org",
+    "system": ["linux_armv6l", "linux_armv7l", "linux_armv8l"],
     "version": "3.30101.0"
 }
 """
@@ -639,7 +650,9 @@ def test_package_json_schema():
         {
             "name": "tool-scons",
             "description": "SCons software construction tool",
+            "keywords": ["scons", "build"],
             "homepage": "http://www.scons.org",
+            "system": ["linux_armv6l", "linux_armv7l", "linux_armv8l"],
             "version": "3.30101.0",
         },
     )
@@ -659,6 +672,20 @@ def test_package_json_schema():
     )
     assert mp.as_dict()["system"] == ["darwin_x86_64"]
 
+    # shortcut repository syntax (npm-style)
+    contents = """
+{
+    "name": "tool-github",
+    "version": "1.2.0",
+    "repository": "github:user/repo"
+}
+"""
+    raw_data = parser.ManifestParserFactory.new(
+        contents, parser.ManifestFileType.PACKAGE_JSON
+    ).as_dict()
+    data = ManifestSchema().load_manifest(raw_data)
+    assert data["repository"]["url"] == "https://github.com/user/repo.git"
+
 
 def test_parser_from_dir(tmpdir_factory):
     pkg_dir = tmpdir_factory.mktemp("package")
@@ -728,7 +755,7 @@ def test_examples_from_dir(tmpdir_factory):
         return re.sub(r"[\\/]+", "/", path)
 
     def _sort_examples(items):
-        for i, item in enumerate(items):
+        for i, _ in enumerate(items):
             items[i]["base"] = _to_unix_path(items[i]["base"])
             items[i]["files"] = [_to_unix_path(f) for f in sorted(items[i]["files"])]
         return sorted(items, key=lambda item: item["name"])
@@ -790,6 +817,21 @@ def test_examples_from_dir(tmpdir_factory):
     )
 
 
+def test_parser_from_archive(tmpdir_factory):
+    pkg_dir = tmpdir_factory.mktemp("package")
+    pkg_dir.join("package.json").write('{"name": "package.json"}')
+    pkg_dir.join("library.json").write('{"name": "library.json"}')
+    pkg_dir.join("library.properties").write("name=library.properties")
+
+    archive_path = os.path.join(str(pkg_dir), "package.tar.gz")
+    with tarfile.open(archive_path, mode="w|gz") as tf:
+        for item in os.listdir(str(pkg_dir)):
+            tf.add(os.path.join(str(pkg_dir), item), item)
+
+    data = parser.ManifestParserFactory.new_from_archive(archive_path).as_dict()
+    assert data["name"] == "library.json"
+
+
 def test_broken_schemas():
     # missing required field
     with pytest.raises(
@@ -825,3 +867,7 @@ def test_broken_schemas():
                 version="1.2.3",
             )
         )
+
+    # invalid package name
+    with pytest.raises(ManifestValidationError, match=("are not allowed")):
+        ManifestSchema().load_manifest(dict(name="C/C++ :library", version="1.2.3"))
